@@ -9,6 +9,7 @@
 from __future__ import division, print_function, unicode_literals
 import concurrent.futures
 import sys
+import traceback
 from contextlib import contextmanager
 
 
@@ -30,14 +31,16 @@ except ImportError:
         from PySide.QtCore import Qt
         QtWidgets = QtGui
 
-from bibtexvcs.vcs import MergeConflict, typeMap, AuthError, VCSInterface
+from bibtexvcs.vcs import MergeConflict, typeMap, AuthError, VCSNotFoundError, VCSInterface
 from bibtexvcs.database import Database, Journal, JournalsFile, DatabaseFormatError
 from bibtexvcs import config
 
+
 def standardIcon(widget, standardPixmap):
     """Helper function to generate a QIcon from a standardPixmap."""
     return widget.style().standardIcon(getattr(widget.style(), standardPixmap))
 
+
 class BtVCSGui(QtWidgets.QWidget):
     """Main window of the BibTeX VCS GUI application.
     """
@@ -85,9 +88,10 @@ class BtVCSGui(QtWidgets.QWidget):
         """Opens the default database as defined in :mod:`bibtexvcs`'s config file. If no default
         database is configured, nothing happens.
         """
-        lastDB = self.future.result()
-        if lastDB:
-            self.setDB(lastDB)
+        with self.catchExceptions():
+            lastDB = self.future.result()
+            if lastDB:
+                self.setDB(lastDB)
 
     def setDB(self, db):
         """Set the current database to `db`."""
@@ -114,7 +118,8 @@ class BtVCSGui(QtWidgets.QWidget):
         if self.db.publicLink:
             self.linkLabel.setText('Web: <a href="{0}">{0}</a>'.format(self.db.publicLink))
         self.linkLabel.setVisible(self.db.publicLink is not None)
-        self.dbLabel.setText("Database: <i>{}</i>".format(self.db.directory))
+        self.dbLabel.setText('Database: <i>{}</i><br />r. {}, changed {}'
+                             .format(self.db.directory, *self.db.vcs.revision()))
         self.setWindowTitle("BibTeX VCS: {}".format(self.db.name))
 
     def runAsync(self, labelText, finishedCall, fn, *args, **kwargs):
@@ -172,8 +177,10 @@ class BtVCSGui(QtWidgets.QWidget):
                     onAuthEntered()
                     return
             M.critical(self, "Authorization Required", str(a))
+        except VCSNotFoundError as e:
+            M.critical(self, 'VCS program not found', str(e))
         except Exception as e:
-            M.critical(self, 'Unhandled exception', str(e))
+            M.critical(self, 'Unhandled {}'.format(type(e)), traceback.format_exc())
 
     def openDialog(self):
         ans = QtWidgets.QFileDialog.getExistingDirectory(self, "Select Database")
@@ -287,19 +294,22 @@ class BtVCSGui(QtWidgets.QWidget):
 
 
 class JournalsWidget(QtWidgets.QWidget):
-
+    """Widget for displaying the journal abbreviations, including buttons to add/remove entries."""
     def __init__(self, db):
         super(JournalsWidget, self).__init__()
         self.table = QtWidgets.QTableWidget(len(db.journals), 3)
-        self.table.setHorizontalHeaderLabels(['Full', 'Abbreviated', 'Macro'])
+        self.table.setHorizontalHeaderLabels(['Macro', 'Abbreviated', 'Full'])
         self.setDB(db)
         fName = 'setSectionResizeMode' if QT5 else 'setResizeMode'
-        getattr(self.table.horizontalHeader(), fName)(0, QtWidgets.QHeaderView.Stretch)
-        getattr(self.table.horizontalHeader(), fName)(1, QtWidgets.QHeaderView.Stretch)
         getattr(self.table.horizontalHeader(), fName)(2, QtWidgets.QHeaderView.ResizeToContents)
+        for i in range(1,3):
+            getattr(self.table.horizontalHeader(), fName)(i, QtWidgets.QHeaderView.Interactive)
+
         getattr(self.table.verticalHeader(), fName)(QtWidgets.QHeaderView.ResizeToContents)
         layout = QtWidgets.QVBoxLayout()
         journalsLabel = QtWidgets.QLabel('<h3>Journals Management</h3>')
+        self.searchEdit = QtWidgets.QLineEdit()
+        self.searchEdit.textChanged.connect(self.search)
         newJournalButton = QtWidgets.QPushButton('&Add Journal')
         delJournalButton = QtWidgets.QPushButton(standardIcon(self, 'SP_TrashIcon'), '&Delete')
         delJournalButton.clicked.connect(self.deleteCurrent)
@@ -307,6 +317,7 @@ class JournalsWidget(QtWidgets.QWidget):
 
         buttonLayout = QtWidgets.QHBoxLayout()
         buttonLayout.addWidget(journalsLabel)
+        buttonLayout.addWidget(self.searchEdit)
         buttonLayout.addStretch()
         buttonLayout.addWidget(newJournalButton)
         buttonLayout.addWidget(delJournalButton)
@@ -317,6 +328,15 @@ class JournalsWidget(QtWidgets.QWidget):
         self.dontUpdate = False
         layout.setContentsMargins(0, 0, 0, 0)
 
+    def search(self, text):
+        for row in range(self.table.rowCount()):
+            hide = True
+            for col in range(self.table.columnCount()):
+                if text in self.table.item(row, col).text():
+                    hide = False
+                    break
+            self.table.setRowHidden(row, hide)
+
     @staticmethod
     def makeItem(text, editable=True):
         item = QtWidgets.QTableWidgetItem(text)
@@ -330,10 +350,11 @@ class JournalsWidget(QtWidgets.QWidget):
         self.table.clearContents()
         self.table.setRowCount(len(self.db.journals))
         for i, journal in enumerate(self.db.journals.values()):
-            self.table.setItem(i, 0, self.makeItem(journal.full))
+            self.table.setItem(i, 0, self.makeItem(journal.macro, False))
             self.table.setItem(i, 1, self.makeItem(journal.abbr))
-            self.table.setItem(i, 2, self.makeItem(journal.macro, False))
+            self.table.setItem(i, 2, self.makeItem(journal.full))
         self.dontUpdate = False
+        self.table.horizontalHeader().resizeSections(QtWidgets.QHeaderView.ResizeToContents)
 
     def deleteCurrent(self):
         currentRow = self.table.currentRow()
@@ -348,7 +369,7 @@ class JournalsWidget(QtWidgets.QWidget):
         for i in range(self.table.rowCount()):
             if self.table.item(i, 2).text() == macro:
                 QtWidgets.QMessageBox.critcical(self.parent(), 'Macro exists',
-                        "The macro '{}' is already chosen by another journal.".format(macro))
+                        "The macro '{}' is already in use by another journal".format(macro))
                 return
         index = self.table.rowCount()
         self.dontUpdate = True
@@ -358,17 +379,20 @@ class JournalsWidget(QtWidgets.QWidget):
         self.table.setItem(index, 0, self.makeItem(macro))
         self.dontUpdate = False
         self.table.setItem(index, 1, self.makeItem(macro))
+        self.table.selectRow(index)
 
     def updateJournalsFile(self):
         if self.dontUpdate:
             return
         journals = []
         for i in range(self.table.rowCount()):
-            journals.append(Journal(full=self.table.item(i, 0).text(),
-                                    abbr=self.table.item(i, 1).text(),
-                                    macro=self.table.item(i, 2).text()))
+            full, abbr, macro = [self.table.item(i, j).text() for j in (0, 1, 2)]
+            if sys.version_info.major == 2 and not isinstance(full, unicode):
+                full, abbr, macro = [unicode(s) for s in (full, abbr, macro)]
+            journals.append(Journal(full=full, abbr=abbr, macro=macro))
         self.db.journals = JournalsFile(journals=journals)
         self.db.journals.write(self.db.journalsPath)
+        self.db.makeJournalBibfiles()
 
 
 class CloneDialog(QtWidgets.QDialog):
@@ -455,7 +479,8 @@ def run():
             window = QtWidgets.QMessageBox(QtWidgets.QMessageBox.Critical,
                                            "New version available",
                                            "A new version of BibTeX VCS ({}) is available. "
-                                           "Please update, then start again.".format(newVersion),
+                                           "Please update (pip install -U bibtexvcs), then start "
+                                           "again.".format(newVersion),
                                            QtWidgets.QMessageBox.Ok)
             window.show()
             window.accepted.connect(app.exit)
